==> mappingkit-6.x-1.2.tar.gz: mappingkit/mappingkit.inc.php <==
<?php
// $Id: mappingkit.inc.php,v 1.1.2.8 2008/09/13 13:50:07 openwereld Exp $

function mapclient_get_url_path($url) {
  $base_dir = dirname($_SERVER['SCRIPT_FILENAME']) .'/';
  if (base_path() != '/') {
    if (strpos($url, base_path()) === 0) {
        $result = $base_dir . substr($url, strlen(base_path()));
//drupal_set_message( var_export(array('url' => $url, 'base_dir' => $base_dir, 'base_path'=>base_path(), 'result'=>$result),true) );
        return $result;
    }
    return preg_replace( base_path(), $base_dir, $url, 1 );
  }
  else {
    return $base_dir . $url;
  }
}

function mappingkit_get_proxy_url($url, $full = FALSE) {
  return mapclient_get_url(variable_get('mapclient_proxy', 'proxy.php'), $full) .'?url='. urlencode($url);
}

/**
 * Get a relative url or optionally a full one.
 */
function mapclient_get_url($path, $full = FALSE) {
  $parts = parse_url($path);
  if (isset($parts['scheme'])) {
    // already a full url
    $url = $path;
  }
  else {
    if ($path[0] == '/') {
      // absolute path for current host
      $url = $path;
    }
    else if (preg_match('/^(node)\/|^(taxonomy)\/|^rss\.xml$/', $path) > 0) {
      // internal mapbuilder config/context paths (with/without clean urls)
      $url = url($path);
    }
    else {
      // relative to base path
      $url = base_path() . $path;
    }
    
    if ($full) {
      // add scheme and host
      // TODO: use same scheme as current one
      $url = 'http://'. $_SERVER['HTTP_HOST'] . $url;
    }
  }
  return $url;
}

function param_string( $params ) {
  $str = '';
  foreach ($params as $key => $value) {
    $str .= '&'. $key .'='. $value;
  }
  return $str;
}

/**
 * Access callback for user wms lists.
 */
function mappingkit_page_user_access($type, $account) {
  // The visitor must be able to access the site's content.
  // For a blog to 'exist' the user must either be able to
  // create new blog entries, or it must have existing posts.
  return $account->uid && user_access('access content')
    && (user_access('create '. $type, $account) || mappingkit_node_type_post_exists($type, $account));
}

/**
 * Helper function to determine if a user has posts of given type already.
 */
function mappingkit_node_type_post_exists($type, $account) {
  return (bool)db_result(db_query_range(db_rewrite_sql("SELECT 1 FROM {node} n WHERE n.type = '$type' AND n.uid = %d AND n.status = 1"), $account->uid, 0, 1));
}

/**
 * Create temporary file and return it's name.
 *
 * @param $extension
 *   File type extension, including a '.'
 * @param $prefix
 *   Prefix of temporary file name.
 * @param $dir
 *   Directory to create the temporary file in.
 */
function mappingkit_tempnam($extension = NULL, $prefix = "dmk", $dir = NULL) {
  if (!$dir) {
    $dir = file_directory_temp();
  }
  $tries = 0;
  do {
    if (!($path = tempnam($dir, $prefix))) {
      return FALSE;
    }
    if (!$extension) {
      return $path;
    }
    else {
      $newpath = $path . $extension;
      if (@rename($path, $newpath)) {
        return $newpath;
      }
      unlink($path);
    }
    $tries += 1;
  } while($tries <= 5);
  return FALSE;
}

==> mappingkit-6.x-1.4.tar.gz: mappingkit/mappingkit.inc.php <==
<?php
// $Id: mappingkit.inc.php,v 1.1.2.9 2008/12/13 21:59:32 openwereld Exp $

function mapclient_get_url_path($url) {
  $base_dir = dirname($_SERVER['SCRIPT_FILENAME']) .'/';
  if (base_path() != '/') {
    if (strpos($url, base_path()) === 0) {
        $result = $base_dir . substr($url, strlen(base_path()));
//drupal_set_message( var_export(array('url' => $url, 'base_dir' => $base_dir, 'base_path'=>base_path(), 'result'=>$result),true) );
        return $result;
    }
    return preg_replace( base_path(), $base_dir, $url, 1 );
  }
  else {
    return $base_dir . $url;
  }
}

function mappingkit_get_proxy_url($url, $full = FALSE) {
  return mapclient_get_url(variable_get('mapclient_proxy', 'proxy.php'), $full) .'?url='. urlencode($url);
}

/**
 * Get a relative url or optionally a full one.
 */
function mapclient_get_url($path, $full = FALSE) {
  $parts = parse_url($path);
  if (isset($parts['scheme'])) {
    // already a full url
    $url = $path;
  }
  else {
    if ($path[0] == '/') {
      // absolute path for current host
      $url = $path;
    }
    else if (preg_match('/^(node)\/|^(taxonomy)\/|^rss\.xml$/', $path) > 0) {
      // internal mapbuilder config/context paths (with/without clean urls)
      $url = url($path);
    }
    else {
      // relative to base path
      $url = base_path() . $path;
    }
    
    if ($full) {
      // add scheme and host (use same scheme as current one)
      global $base_url;
      $url = parse_url($base_url, PHP_URL_SCHEME) . '://'. $_SERVER['HTTP_HOST'] . $url;
    }
  }
  return $url;
}

function param_string( $params ) {
  $str = '';
  foreach ($params as $key => $value) {
    $str .= '&'. $key .'='. $value;
  }
  return $str;
}

/**
 * Access callback for user wms lists.
 */
function mappingkit_page_user_access($type, $account) {
  // The visitor must be able to access the site's content.
  // For a blog to 'exist' the user must either be able to
  // create new blog entries, or it must have existing posts.
  return $account->uid && user_access('access content')
    && (user_access('create '. $type, $account) || mappingkit_node_type_post_exists($type, $account));
}

/**
 * Helper function to determine if a user has posts of given type already.
 */
function mappingkit_node_type_post_exists($type, $account) {
  return (bool)db_result(db_query_range(db_rewrite_sql("SELECT 1 FROM {node} n WHERE n.type = '$type' AND n.uid = %d AND n.status = 1"), $account->uid, 0, 1));
}

/**
 * Create temporary file and return it's name.
 *
 * @param $extension
 *   File type extension, including a '.'
 * @param $prefix
 *   Prefix of temporary file name.
 * @param $dir
 *   Directory to create the temporary file in.
 */
function mappingkit_tempnam($extension = NULL, $prefix = "dmk", $dir = NULL) {
  if (!$dir) {
    $dir = file_directory_temp();
  }
  $tries = 0;
  do {
    if (!($path = tempnam($dir, $prefix))) {
      return FALSE;
    }
    if (!$extension) {
      return $path;
    }
    else {
      $newpath = $path . $extension;
      if (@rename($path, $newpath)) {
        return $newpath;
      }
      unlink($path);
    }
    $tries += 1;
  } while($tries <= 5);
  return FALSE;
}
